@@ -2,7 +2,7 @@ from typing import Union
 from urllib.request import urlretrieve
 
 from lamin_logger import logger
-from lamindb_schema import id
+from lnschema_core import id
 from supabase import create_client
 
 from ._settings_load import load_or_create_user_settings
