@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from pathlib import Path
-from typing import Union
+from typing import Optional, Union
 
 import sqlmodel as sqm
 from appdirs import AppDirs
@@ -49,6 +49,7 @@ class Storage:
 
 class instance_description:
     storage_dir = """Storage root. Either local dir, ``s3://bucket_name`` or ``gs://bucket_name``."""  # noqa
+    storage_region = """Cloud storage region for s3 and gcp"""
     _dbconfig = """Either "sqlite" or "instance_name, postgres_url"."""
     name = """Instance name."""
     schema_modules = """Comma-separated string of schema modules."""
@@ -64,6 +65,8 @@ class InstanceSettings:
 
     storage_dir: Union[CloudPath, Path] = None
     """Storage root. Either local dir, ``s3://bucket_name`` or ``gs://bucket_name``."""
+    storage_region: Optional[str] = None
+    """Cloud storage region for s3 and gcp."""
     _dbconfig: str = "sqlite"
     """Either "sqlite" or "instance_name, postgres_url"."""
     schema_modules: str = None  # type: ignore
