@@ -74,7 +74,7 @@ def login(
     if user_settings.password is None:
         raise RuntimeError(
             "No stored user password, please call: lndb login --email <your-email>"
-            " --email <your-password>"
+            " --password <your-password>"
         )
 
     response = sign_in_hub(
